from sinta.affil_scraper import affil, affil_authors
from sinta.author_scraper import author
from sinta.comm_svc_scraper import author_comm_services, dept_comm_services
from sinta.dept_scraper import dept_authors
from sinta.ipr_scraper import author_ipr, dept_ipr
from sinta.research_scraper import author_researches, dept_researches
from sinta.scholar_documents_scraper import author_scholar, dept_scholar
from sinta.scopus_documents_scraper import author_scopus, author_scopus_journal, \
    author_scopus_conference, dept_scopus
from sinta.wos_documents_scraper import author_wos, dept_wos
